@@ -12,6 +12,7 @@ __all__ = [
     "delete_tone",
     "dict_trie",
     "digit_to_text",
+    "display_thai_char",
     "eng_to_thai",
     "find_keyword",
     "is_native_thai",
@@ -67,7 +68,8 @@ from pythainlp.util.normalize import (
 )
 from pythainlp.util.numtoword import bahttext, num_to_thaiword
 from pythainlp.util.strftime import thai_strftime
-from pythainlp.util.thai import countthai, isthai, isthaichar
+from pythainlp.util.thai import countthai, isthai, isthaichar, \
+    display_thai_char
 from pythainlp.util.thaiwordcheck import is_native_thai
 from pythainlp.util.time import thai_time, thaiword_to_time, time_to_thaiword
 from pythainlp.util.trie import Trie, dict_trie
